diff PalanthirCppClient/main.cpp @ 50:a15e90e5d6fc

rename in code
author Sebastien Jodogne <s.jodogne@gmail.com>
date Wed, 05 Sep 2012 15:50:12 +0200
parents 33d67e1ab173
children
line wrap: on
line diff
--- a/PalanthirCppClient/main.cpp	Wed Sep 05 15:38:08 2012 +0200
+++ b/PalanthirCppClient/main.cpp	Wed Sep 05 15:50:12 2012 +0200
@@ -1,5 +1,5 @@
 /**
  * Palantir - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium
  *
@@ -32,7 +32,7 @@
 int main()
 {
   // Prepare a simple call to a Web service
-  Palantir::HttpClient c;
+  Palanthir::HttpClient c;
   c.SetUrl("http://nominatim.openstreetmap.org/search?format=json&q=chu+liege+belgium");
   
   // Do the request and store the result in a JSON structure
@@ -1,5 +1,5 @@
 /**
- * Palantir - A Lightweight, RESTful DICOM Store
+ * Palanthir - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium